@@ -19,9 +19,10 @@ Outputs = container.ndarray
 
 __all__ = ('IPCMBplus_Selector',)
 
-# class Params(params.Params):
-#     n_features: int
-#     feature_index: ndarray
+class Params(params.Params):
+    pass
+#    n_features: int
+#    feature_index: ndarray
 
 
 class Hyperparams(hyperparams.Hyperparams):
@@ -61,7 +62,7 @@ class IPCMBplus_Selector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params,
 
     metadata = metadata_module.PrimitiveMetadata({
         'id': '69845479-0b61-3578-b382-972cd0e61d69',
-        'version': '2.0.5',
+        'version': '2.0.7',
         'name': 'IPCMB feature selector',
         'keywords': 'rpi primitives',
         'source': {
